@@ -273,7 +273,7 @@ class GringoClaspBase:
         self._gringo = None
         self.clasp_stderr = None
         self.gringo_stderr = None
-        self.clasp_noerror_retval = set([10, 20])
+        self.clasp_noerror_retval = set([10, 20, 30])
         self.gringo_noerror_retval = set([0])
 
     def getClaspStderr(self):
@@ -337,7 +337,7 @@ class GringoClasp(GringoClaspBase):
               addoptions = self.gringo_options.split()
               assert(addoptions.__class__ == list)
 
-            commandline = filter_empty_str([self.gringo_bin, '-l'] + addoptions + programs + additionalPrograms)
+            commandline = filter_empty_str([self.gringo_bin] + addoptions + programs + additionalPrograms)
             #debug(commandline)
             self._gringo = subprocess.Popen(
               commandline, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
@@ -443,7 +443,7 @@ class GringoClasp(GringoClaspBase):
               addoptions = self.gringo_options.split()
               assert(addoptions.__class__ == list)
 
-            commandline = filter_empty_str([self.gringo_bin, '-l'] + addoptions + programs + additionalPrograms)
+            commandline = filter_empty_str([self.gringo_bin] + addoptions + programs + additionalPrograms)
             #debug(commandline)
             self._gringo = subprocess.Popen(
               commandline, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
@@ -511,10 +511,10 @@ class GringoClasp(GringoClaspBase):
         self._gringo = None
         return count
 
-class GringoUnClasp(GringoClaspBase):
+class GringoHClasp(GringoClaspBase):
     def __init__(self, *args, **keywords):
         GringoClaspBase.__init__(self, *args, **keywords)
-        self.clasp_bin = root + '/bin/unclasp'
+        self.clasp_bin = root + '/bin/hclasp'
         self.clasp_noerror_retval = set([0,10,20])
 
     def run(self, programs, nmodels = 1, collapseTerms=True, collapseAtoms=True, additionalProgramText=None):
@@ -535,7 +535,7 @@ class GringoUnClasp(GringoClaspBase):
               addoptions = self.gringo_options.split()
               assert(addoptions.__class__ == list)
 
-            commandline = filter_empty_str([self.gringo_bin, '-l'] + addoptions + programs + additionalPrograms)
+            commandline = filter_empty_str([self.gringo_bin] + addoptions + programs + additionalPrograms)
             #debug(commandline)
             self._gringo = subprocess.Popen(
               commandline, stderr=subprocess.PIPE, stdout=subprocess.PIPE)
@@ -664,7 +664,7 @@ class GringoClaspOpt(GringoClaspBase):
           additionalPrograms.append(fn)
           
         self._gringo = subprocess.Popen(
-            filter_empty_str([self.gringo_bin, '-l'] +
+            filter_empty_str([self.gringo_bin] +
               self.gringo_options.split() + programs + additionalPrograms),
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE)
@@ -793,7 +793,7 @@ class GringoClaspDistr(GringoClaspBase):
         # options need to be filtered to work with Popen
         # since gringo/clasp doesn't like whitespace before numbers parameter
         self._gringo = subprocess.Popen(
-            filter_empty_str([self.gringo_bin, '-l'] + self.gringo_options.split() + programs),
+            filter_empty_str([self.gringo_bin] + self.gringo_options.split() + programs),
             stdout=subprocess.PIPE,
             stderr=subprocess.PIPE)
         self._clasp = subprocess.Popen(
